@@ -1,21 +1,22 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Authors: Michael Zucchi <notzed@ximian.com>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; version 2 of the License.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Authors:
+ *		Michael Zucchi <notzed@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -405,7 +406,7 @@ ecalp_standard_menu_factory (EPopup *ecalp, void *data)
 			if (filename) {
 				gchar *name_type;
 
-				name_type = e_util_guess_mime_type (filename);
+				name_type = e_util_guess_mime_type (filename, FALSE);
 				apps = g_app_info_get_all_for_type (name_type);
 				g_free (name_type);
 			}
@@ -694,7 +695,7 @@ e_cal_popup_target_new_source(ECalPopup *eabp, ESourceSelector *selector)
 {
 	ECalPopupTargetSource *t = e_popup_target_new(&eabp->popup, E_CAL_POPUP_TARGET_SOURCE, sizeof(*t));
 	guint32 mask = ~0;
-	const char *source_uri;
+	const char *relative_uri;
 	char *uri;
 	ESource *source;
 	const char *offline = NULL;
@@ -711,42 +712,32 @@ e_cal_popup_target_new_source(ECalPopup *eabp, ESourceSelector *selector)
 		mask &= ~E_CAL_POPUP_SOURCE_PRIMARY;
 
 	/* FIXME Gross hack, should have a property or something */
-	source_uri = e_source_peek_relative_uri(source);
-	if (source_uri && !strcmp("system", source_uri))
+	relative_uri = e_source_peek_relative_uri(source);
+	if (relative_uri && !strcmp("system", relative_uri))
 		mask &= ~E_CAL_POPUP_SOURCE_SYSTEM;
 	else
 		mask &= ~E_CAL_POPUP_SOURCE_USER;
 
-	source = e_source_selector_peek_primary_selection (selector);
 	uri = e_source_get_uri (source);
 	if (!uri || (g_ascii_strncasecmp (uri, "file://", 7) && g_ascii_strncasecmp (uri, "contacts://", 11))) {
 		/* check for e_target_selector's offline_status property here */
-		offline = e_source_get_property (source, "offline");
-
-		if (offline  && strcmp (offline,"1") == 0) {
-			/* set the menu item to Mark Offline - */
-			mask &= ~E_CAL_POPUP_SOURCE_NO_OFFLINE;
-		} else {
+		offline = e_source_get_property (source, "offline_sync");
+		if (offline  && strcmp (offline, "1") == 0)
+			mask &= ~E_CAL_POPUP_SOURCE_NO_OFFLINE; 	/* set the menu item to Mark Offline */
+		else
 			mask &= ~E_CAL_POPUP_SOURCE_OFFLINE;
-		}
 	} else {
 		mask |= E_CAL_POPUP_SOURCE_NO_OFFLINE;
 		mask |= E_CAL_POPUP_SOURCE_OFFLINE;
 	}
 	g_free (uri);
 
-	source = e_source_selector_peek_primary_selection (selector);
-	/*check for delete_status property here*/
+	/* check for delete_status property here */
 	delete = e_source_get_property (source, "delete");
-
-	if (delete && strcmp (delete,"no") == 0) {
-		/*set the menu item to non deletable */
-		mask &= ~E_CAL_POPUP_SOURCE_NO_DELETE;
-	}
-	else {
+	if (delete && strcmp (delete, "no") == 0)
+		mask &= ~E_CAL_POPUP_SOURCE_NO_DELETE; 			/* set the menu item to non deletable */
+	else
 		mask &= ~E_CAL_POPUP_SOURCE_DELETE;
-	}
-
 
 	t->target.mask = mask;
 
